pub struct JavaScriptNativeInterface {}Implementations
Sourceimpl JavaScriptNativeInterface
impl JavaScriptNativeInterface
pub fn new() -> Self
Sourcepub async fn call(
&mut self,
js_func_name: String,
args: Vec<JSNIValue>,
) -> Vec<JSNIValue>
pub async fn call( &mut self, js_func_name: String, args: Vec<JSNIValue>, ) -> Vec<JSNIValue>
Calls the JavaScript function. Must be set registers with uarguments to pass to the JavaScript function before calling this function. Returns a vector of results. The first register is the count of results, followed by the results themselves.